==> python_trueconf_bot-1.0.0.tar.gz: python_trueconf_bot-1.0.0/docs/en/reference/Types.md <==
---
title: Types
icon: 
---

#  Types

You can import all types at once:

```python
from trueconf.types import *
```

::: trueconf.types.AddedChatParticipant
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.CreatedChannel
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"


::: trueconf.types.CreatedGroupChat
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.CreatedPersonalChat
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.EditedMessage
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.Message
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.RemovedChat
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.RemovedChatParticipant
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.RemovedMessage
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.Update
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.UploadingProgress
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

==> python_trueconf_bot-1.1.2.tar.gz: python_trueconf_bot-1.1.2/docs/en/reference/Types.md <==
---
title: Types
icon: 
---

#  Types

You can import all types at once:

```python
from trueconf.types import *
```

::: trueconf.types.AddedChatParticipant
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.ChangedParticipantRole
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.CreatedChannel
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"


::: trueconf.types.CreatedGroupChat
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.CreatedPersonalChat
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.EditedMessage
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.InputFile
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.BufferedInputFile
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.FSInputFile
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.URLInputFile
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"


::: trueconf.types.Message
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.RemovedChat
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.RemovedChatParticipant
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.RemovedMessage
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.Update
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"

::: trueconf.types.UploadingProgress
    options:
        filters:
            - "!^_"
            - "!^__"
            - "!bot"
            - "!bind"
